@@ -1,3 +1,5 @@
+
+
 """
     The bridgeobjects package exposes the following classes:
     (inspect the individual modules to see their APIs):
@@ -16,23 +18,18 @@
     file_operations: a module to load or save events in a PBN, RBN or LIN format.
 """
 
-from ._version import __version__
-VERSION = __version__
-
 from bridgeobjects.source.constants import *
 from bridgeobjects.source.board import *
 from bridgeobjects.source.hand import *
 from bridgeobjects.source.card import *
 from bridgeobjects.source.suit import *
-# from bridgeobjects.source.denomination import *
 from bridgeobjects.source.auction import *
 from bridgeobjects.source.contract import *
 from bridgeobjects.source.call import *
 from bridgeobjects.source.event import *
 from bridgeobjects.source.trick import *
 from bridgeobjects.source.file_operations import *
+from bridgeobjects.source.denomination import * # type: ignore
 
-
-# from bridgeobjects.tests.xxx_load_pbn import *
-
-# from bridgeobjects.tests.test_rbn import *
\ No newline at end of file
+from ._version import __version__
+VERSION = __version__
