@@ -29,7 +29,7 @@ class Auction(object):
 
     def __init__(self, calls: Union[List[Call], None]=None, first_caller: str=''):
         """Create an auction with the given calls and first_caller."""
-        self.first_caller = first_caller
+        self._first_caller = first_caller
         if not calls:
             calls = []
         self._calls = []
@@ -39,6 +39,7 @@ class Auction(object):
             self._calls.append(call)
         self._note_keys: List[str] = []
         self._notes: Dict[str, str] = {}
+        self.seat_calls = self._get_seat_calls()
 
     def __repr__(self) -> str:
         """Return the repr string for the object."""
@@ -67,6 +68,7 @@ class Auction(object):
             if value not in SEATS:
                 raise ValueError(f'{value} is not a valid seat')
         self._first_caller = value
+        self.seat_calls = self._get_seat_calls()
 
     @property
     def calls(self)-> List[Call]:
@@ -115,3 +117,16 @@ class Auction(object):
         if not isinstance(value, dict):
             raise TypeError('Notes must be a dict')
         self._note_keys = value
+
+    def _get_seat_calls(self) -> Dict[str, List[Call]]:
+        """Return a dict of calls by seat."""
+        seat_calls = {seat: [] for seat in SEATS}
+        if not self._first_caller:
+            return seat_calls
+
+        seat_index = SEATS.index(self._first_caller)
+        for call in self.calls:
+            seat_calls[SEATS[seat_index]].append(call)
+            seat_index += 1
+            seat_index %= 4
+        return seat_calls
