@@ -1,9 +1,9 @@
 """Constants used in many bridgeobjects modules."""
 
-__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES',  'RANKS',
-           'SUITS', 'BALANCED_SHAPES', 'SEMI_BALANCED_SHAPES',
-           'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS',
-           'CARD_NAMES', 'CARD_VALUES', 'DISPLAY_SUIT_ORDER']
+__all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES', 'DENOMINATION_NAMES',
+            'RANKS', 'SUITS', 'BALANCED_SHAPES', 'SEMI_BALANCED_SHAPES',
+            'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS',
+            'CARD_NAMES', 'CARD_VALUES', 'DISPLAY_SUIT_ORDER']
 
 from typing import List
 
@@ -51,6 +51,9 @@ CONTRACTS = _make_contracts()
 #: Suit names list
 SUIT_NAMES = ['C', 'D', 'H', 'S']
 
+#: Denomination names list
+DENOMINATION_NAMES = ['C', 'D', 'H', 'S', 'NT']
+
 #: card ranks
 RANKS = ['x', '2', '3', '4', '5', '6', '7', '8', '9', 'T', 'J', 'Q', 'K', 'A']
 
@@ -85,6 +88,19 @@ CARD_VALUES = {
     '4': 3,
     '3': 2,
     '2': 1,
+    13: 'A',
+    12: 'K',
+    11: 'Q',
+    10: 'J',
+    9: 'T',
+    8: '9',
+    7: '8',
+    6: '7',
+    5: '6',
+    4: '5',
+    3: '4',
+    2: '3',
+    1: '2',
 }
 
 
