@@ -96,6 +96,8 @@ class Contract(object):
             if not self._is_nt:
                 self._trump_suit = SUITS[value[1]]
         self._name = value
+        self._level = int(self._name[0])
+        self._target_tricks = self._level + 6
         self._call = Call(self._name)
 
     @property
