@@ -18,7 +18,7 @@ from .suit import Suit
 from .trick import Trick
 from .contract import Contract
 from .auction import Auction
-from .constants import SUIT_NAMES, RANKS, CALLS, SEATS, CONTRACTS, CARD_NAMES
+from .constants import SUIT_NAMES, RANKS, CALLS, SEATS, CONTRACTS, CARD_NAMES, DENOMINATION_NAMES
 
 PBN_VULNERABILITY_CONVERSION = {'Z': 'None', 'N': 'NS', 'E': 'EW',
                                 'B': 'Both', '?': '',
@@ -117,6 +117,7 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
     auction_state = False
     play_state = False
     board_state = False
+    result_table = False
     board_index = 0
     events = []
     event = Event()
@@ -134,6 +135,8 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                     auction_state = False
                 elif play_state and tag != 'Note':
                     play_state = False
+                elif result_table and tag != 'Note':
+                    result_table = False
                 elif line.startswith('{'):
                     if board_state and tag == 'Description':
                         board.description = value
@@ -219,6 +222,13 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                 board.contract.declarer = value
                 board.declarer = value
 
+            # Declarer
+            elif tag == "Result":
+                if value == '?':
+                    value = -1
+                if value.isnumeric():
+                    board.declarers_tricks = int(value)
+
             # # Description
             # elif tag == "Description":
             #     board.description = value
@@ -253,6 +263,15 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                     # board.tricks[trick_index] = trick
                     board.tricks.append(trick)
                     trick_index += 1
+
+            # Optimum results
+            elif tag == "OptimumResultTable":
+                result_table = True
+            elif result_table:
+                while '  ' in line:
+                    line = line.replace('  ', ' ')
+                result = line.split(' ')
+                board.optimum_result_table[result[0]][result[1]] = result[2]
     return events
 
 
@@ -893,6 +912,10 @@ def create_pbn_board(event: Event, board: Board) -> List[str]:
         output.append(f'[Scoring {_question_from_null(event.scoring_method)}]')
     output.append(f'[Declarer {_question_from_null(board.contract.declarer)}]')
     if board.contract.call:
+        if board.contract.declarer and board.contract.denomination:
+            result = board.optimum_result_table[board.contract.declarer][board.contract.denomination.name]
+            if result:
+                board.result = result
         question = _question_from_null(board.contract.call.name)
         output.append(f'[Contract {question}]')
     if board.auction.calls:
@@ -900,10 +923,20 @@ def create_pbn_board(event: Event, board: Board) -> List[str]:
     output.append(f'[Result {_question_from_null(board.result)}]')
     if board.tricks:
         output.extend(_create_pbn_play_section(board))
-    output.append('')
     if board.play_notes:
         for key in board.play_notes:
             note = f'[Note "{key}:{board.play_notes[key]}"]'
             output.append(note)
-        output.append('')
+
+    # optimum result table
+    results_tag = False
+    for seat in SEATS:
+        for denomination in DENOMINATION_NAMES:
+            if board.optimum_result_table[seat][denomination]:
+                if not results_tag:
+                    output.append(f'[OptimumResultTable "Declarer;Denomination\\2R;Result\\2R"]')
+                    results_tag = True
+                output.append(f'{seat}{denomination:>3}{board.optimum_result_table[seat][denomination]:>3}')
+
+    output.append('')
     return output
