@@ -699,10 +699,11 @@ def test_hand_honours():
     assert hand.honours == {'S': 2, 'H':3, 'D':1, 'C': 2}
 
 
-def test_hand_high_card_left_default():
-    """Ensure the hand's high_card_left default is correct."""
-    hand = Hand(hand_list_6332)
-    assert hand.high_card_left
+# No longer set at hand level default is True
+# def test_hand_high_card_left_default():
+#     """Ensure the hand's high_card_left default is correct."""
+#     hand = Hand(hand_list_6332)
+#     assert hand.high_card_left
 
 
 def test_hand_rule_of_twenty():
@@ -800,12 +801,13 @@ def test_internal_sequences():
     assert Hand(hand_list_5611).internal_sequences() == [Card('TH')]
 
 
-def test_hand_high_card_left_setter():
-    """Ensure the hand's high_card_left is correct."""
-    hand = Hand(hand_list_6332)
-    with pytest.raises(TypeError) as exc_info:
-        hand.high_card_left = 1
-    assert True
+# No longer set at hand level default is True
+# def test_hand_high_card_left_setter():
+#     """Ensure the hand's high_card_left is correct."""
+#     hand = Hand(hand_list_6332)
+#     with pytest.raises(TypeError) as exc_info:
+#         hand.high_card_left = 1
+#     assert True
 
 
 def test_sorted_cards():
@@ -832,8 +834,8 @@ def test_sorted_cards():
     assert cards[0] == Card('5H')
     assert cards[-1] == Card('QC')
 
-    hand.high_card_left = False
-    cards = hand.sorted_cards('HSDC')
+    # hand.high_card_left = False
+    cards = hand.sorted_cards('HSDC', False)
     assert cards[0] == Card('5H')
     assert cards[-1] == Card('QC')
 
